Learn R Programming

hmsr (version 1.0.1)

lsc_metaepochs_without_improvement: Factory function for a local stopping condition that stops a deme after given number of consecutive metaeopochs without an improvement of the best solution found in that deme.

Description

Factory function for a local stopping condition that stops a deme after given number of consecutive metaeopochs without an improvement of the best solution found in that deme.

Usage

lsc_metaepochs_without_improvement(max_metaepochs_without_improvement)

Value

Function that can be used as a local stopping condition for hms.

Arguments

max_metaepochs_without_improvement
  • numeric

Examples

Run this code
local_stopping_condition <- lsc_metaepochs_without_improvement(5)

Run the code above in your browser using DataLab