Learn R Programming

hmsr (version 1.0.1)

lsc_trivial: Factory function for a trivial local stopping condition that lets a deme be active forever. It is usually used in the root of a hms tree.

Description

Factory function for a trivial local stopping condition that lets a deme be active forever. It is usually used in the root of a hms tree.

Usage

lsc_trivial()

Arguments

Value

Function that always returns FALSE, which can be used as a local stopping condition for hms.

Examples

Run this code
local_stopping_condition <- lsc_trivial()

Run the code above in your browser using DataLab