powered by
It allows an individual to sprout only if there are no other demes on the target level that have centroid within the given distance.
sc_max_metric(metric, max_distances)
Function that can be used as a sprouting condition of hms.
Metric used for deme distance comparison (e.g. euclidean_distance, manhattan_distance)
numeric - maximum distance to a centroid of a deme on the target level that would allow the individual to sprout
sprouting_condition <- sc_max_metric(euclidean_distance, c(20, 10))
Run the code above in your browser using DataLab