Learn R Programming

hmsr (version 1.0.1)

show,hms-method: Show method for class "hms".

Description

Show method for class "hms".

Usage

# S4 method for hms
show(object)

Value

It returns the names of the slots and the classes associated with the slots in the "hms" class. It prints call details.

Arguments

object
  • hms s4 object

Examples

Run this code
f <- function(x) x
result <- hms(fitness = f, lower = -5, upper = 5)
show(result)

Run the code above in your browser using DataLab