Learn R Programming

hmsr (version 1.0.1)

ga_metaepoch: Function that runs one GA metaepoch. Wrapper function for GA::ga.

Description

Function that runs one GA metaepoch. Wrapper function for GA::ga.

Usage

ga_metaepoch(config_ga)

Value

list with named fields: solution, population, value. A solution is a value of the decision variable giving the best fitness. A population is a matrix representing final population. Value is the value of a fitness function for the solution.

Arguments

config_ga
  • list of GA::ga params

Examples

Run this code
tree_height <- 3
empty_config_ga <- lapply(1:tree_height, function(x) {
  list()
})
ga_metaepoch(empty_config_ga)

Run the code above in your browser using DataLab