gsc_max_fitness_evaluations: Factory function for a global stopping condition that stops
the computation after fitness function has been evaluated
given number of times.
Description
Factory function for a global stopping condition that stops
the computation after fitness function has been evaluated
given number of times.
Usage
gsc_max_fitness_evaluations(max_evaluations)
Value
Function that receives a list of metaepoch snapshots
and returns a Boolean value determining whether the computation
should be stopped based on how many fitness function evaluations
have been made, which can be used as a global stopping condition
for the hms function.
Arguments
max_evaluations
numeric - maximum number of fitness function evaluations