gsc_metaepochs_count: Factory function for a global stopping condition that stops
the computation after given number of metaepochs.
Description
Factory function for a global stopping condition that stops
the computation after given number of metaepochs.
Usage
gsc_metaepochs_count(metaepochs_count)
Value
Function that receives a list of metaepoch snapshots
and returns a Boolean value determining whether the computation
should be stopped based on how many metaepochs have passed,
which can be used as a global stopping condition for the hms function.