gsc_trivial: Factory function for a global stopping condition that never stops
the computation. It results in hms running until there are no more
active demes.
Description
Factory function for a global stopping condition that never stops
the computation. It results in hms running until there are no more
active demes.
Usage
gsc_trivial()
Arguments
Value
function that always returns FALSE, which can be used
as a global stopping condition for the hms function.