lsc_max_fitness_evaluations: Factory function for a local stopping condition that stops a deme
after given number of fitness function evaluations has been made
in that deme.
Description
Factory function for a local stopping condition that stops a deme
after given number of fitness function evaluations has been made
in that deme.
Usage
lsc_max_fitness_evaluations(max_evaluations)
Value
Function that can be used as a local stopping condition for hms.