powered by
Factory function for a trivial local stopping condition that lets a deme be active forever. It is usually used in the root of a hms tree.
lsc_trivial()
Function that always returns FALSE, which can be used as a local stopping condition for hms.
FALSE
local_stopping_condition <- lsc_trivial()
Run the code above in your browser using DataLab